package com.caimei365.manager.controller.caimei.user;

import com.caimei.utils.StringUtils;
import com.caimei365.manager.entity.PaginationVo;
import com.caimei365.manager.entity.ResponseJson;
import com.caimei365.manager.entity.caimei.CmShop;
import com.caimei365.manager.entity.caimei.shopImport.CmMarketReport;
import com.caimei365.manager.entity.caimei.shopImport.CmMarketShop;
import com.caimei365.manager.service.caimei.user.CmMarketShopService;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

import javax.annotation.Resource;
import java.io.IOException;
import java.util.Map;

/**
 * Description
 *
 * @author : hzg
 * @date : 2023/12/14
 */
@RestController
@RequestMapping("/user/market")
public class CmMarketShopApi {

    @Resource private CmMarketShopService marketShopService;

    /**
     * 上传供应商营销logo
     * @param id
     * @param logo
     * @return
     */
    @GetMapping("/uploadShopLogo")
    public ResponseJson uploadShopLogo(Integer id, String logo) {
        if (null == id) {
            return  ResponseJson.error(-1, "供应商营销id不能为空", null);
        }
        if (StringUtils.isBlank(logo) || StringUtils.isEmpty(logo)) {
            return  ResponseJson.error(-1, "供应商营销id不能为空", null);
        }
        return marketShopService.uploadShopLogo(id, logo);
    }

    /**
     * 数据报表列表
     * @param marketId
     * @param reportName
     * @param pageNum
     * @param pageSize
     * @return
     */
    @GetMapping("/getMarketReport")
    public ResponseJson<PaginationVo<CmMarketReport>> getMarketReport(Integer marketId, String reportName,
                                                                      @RequestParam(value = "pageNum", defaultValue = "1") int pageNum,
                                                                      @RequestParam(value = "pageSize",defaultValue = "20") int pageSize) {
        if (null == marketId) {
            return  ResponseJson.error(-1, "供应商营销id不能为空", null);
        }
        return marketShopService.getMarketReport(marketId, reportName, pageNum, pageSize);
    }

    /**
     * 编辑回显
     * @param id
     * @return
     */
    @GetMapping("/getMarketReportById")
    public ResponseJson<CmMarketReport> getMarketReportById(Integer id) {
        if (null == id) {
            return  ResponseJson.error(-1, "供应商营销id不能为空", null);
        }
        return marketShopService.getMarketReportById(id);
    }

    /**
     * 启用数据报表
     * @param id
     * @return
     */
    @GetMapping("/updateVisible")
    public ResponseJson updateVisible(Integer id) {
        if (null == id) {
            return  ResponseJson.error(-1, "供应商营销id不能为空", null);
        }
        return marketShopService.updateMarketReportVisible(id);
    }

    /**
     * 删除数据报表
     * @param id
     * @return
     */
    @GetMapping("/deleteMarketReport")
    public ResponseJson deleteMarketReport(Integer id) {
        if (null == id) {
            return  ResponseJson.error(-1, "供应商营销id不能为空", null);
        }
        return marketShopService.updateMarketReport(id);
    }

    /**
     * 上传zip、rar文件到服务器并解压
     * @return
     */
    @PostMapping("/saveMarketReport")
    public ResponseJson saveMarketReport(@RequestParam("reportFile") MultipartFile reportFile) throws IOException {

        if (reportFile.isEmpty() || reportFile == null) {
            return ResponseJson.error(-1, "报表文件不能为空", null);
        }
        return marketShopService.saveMarketReport(reportFile);
    }

    /**
     * 保存报表数据
     * @param marketId
     * @param id
     * @param reportDate
     * @param reportName
     * @param filePath
     * @return
     * @throws IOException
     */
    @GetMapping("/saveReport")
    public ResponseJson saveReport(Integer marketId, Integer id, String reportDate, String reportName, String filePath) throws IOException {
        if (marketId == null) {
            return ResponseJson.error(-1, "供应商营销Id不能为空", null);
        }
        if (StringUtils.isBlank(reportDate) || StringUtils.isEmpty(reportDate)) {
            return ResponseJson.error(-1, "报表时间不能为空", null);
        }
        if (StringUtils.isBlank(reportName) || StringUtils.isEmpty(reportName)) {
            return ResponseJson.error(-1, "报表名称不能为空", null);
        }
        if (StringUtils.isBlank(filePath) || StringUtils.isEmpty(filePath)) {
            return ResponseJson.error(-1, "报表路径不能为空", null);
        }
        return marketShopService.saveReport(marketId, id, reportDate, reportName, filePath);
    }

    /**
     * 报表数据预览
     * @param id
     * @return
     */
    @GetMapping("/preview")
    public ResponseJson<Map<String, Object>> preview(Integer id) {
        if (id == null) {
            return ResponseJson.error(-1, "报表id不能为空", null);
        }
        return marketShopService.preview(id);
    }

}
