package com.caimei365.manager.dao;

import com.caimei365.manager.entity.caimei.CmKeywordInfo;
import com.caimei365.manager.entity.caimei.CmKeywordSubtag;
import com.caimei365.manager.entity.caimei.CmPriorKeyword;
import com.caimei365.manager.entity.caimei.KeyWord;
import com.caimei365.manager.entity.caimei.cmUser.ServiceProviderModel;
import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;

import java.util.Date;
import java.util.List;
import java.util.Map;

/**
 * @author zzj
 */
@Mapper
public interface KeyWordDao {
    List<KeyWord> findList(String keyword, Integer fromSearch, String beginTime, String endTime, Integer labelStatus);

    void updateLabelStatus(String id);

    List<KeyWord> findRecommendList(String keyword, String beginTime, String endTime);

    void updateRecommendFlag(String id);

    void insertLabel(String keyword);

    void insertLabelByExcel(String keyword);

    Integer findKeywordExist(String keyword);

    /**
     * 是否已存在
     * @param keyword
     * @return
     */
    Integer getKeywordByName(String keyword);

    Map<String, String> findLinkageStatus(String id);

    void updateDelFlag(String id);

    void updateCmUserSearchFrequency(KeyWord keyWord);

    /**
     * 协销列表
     * @return
     */
    List<ServiceProviderModel> getServiceList();

    /**
     * 静态标签列表
     * @param dynamicStatus
     * @param parentLabel
     * @param keyword
     * @param fromSearch
     * @param beginTime
     * @param endTime
     * @param serviceProviderId
     * @return
     */
    List<CmKeywordInfo> getStateKeyWordList(Integer dynamicStatus, Integer parentLabel, String keyword, Integer fromSearch, String beginTime, String endTime, Integer serviceProviderId);

    /**
     * 动态标签编辑
     * @param id
     * @return
     */
    CmKeywordInfo getkeywordById(@Param("id") Integer id);

    /**
     * 动态标签子标签集合
     * @param id
     * @return
     */
    List<CmKeywordSubtag> getkeywordSubtag(@Param("id") Integer id);

    /**
     * 获取所有子标签
     * @param keyword
     * @return
     */
    List<CmKeywordInfo> getKeyword(@Param("keyword") String keyword);

    /**
     * 插入 动态/静态标签
     * @param cmKeywordInfo
     */
    void insertKeywordInfo(CmKeywordInfo cmKeywordInfo);

    /**
     * 修改标签数据
     * @param cmKeywordInfo
     */
    void updateKeyword(CmKeywordInfo cmKeywordInfo);

    /**
     * 添加子标签与父标签的关联
     * @param subtag
     */
    void insertKeywordSubtag(CmKeywordSubtag subtag);

    /**
     * 删除与父标签的关联
     * @param keywordId
     * @param ids
     */
    void updateKeywordSubtag(@Param("keywordId") Integer keywordId, @Param("ids") List<Integer> ids);
    /**
     * 删除动态/静态标签
     * @param id
     */
    void updateKeywordInfo(@Param("id") String id);
    /**
     * 优先展示标签
     * @param keyword
     * @param fromSearch
     * @param dynamicStatus
     * @return
     */
    List<CmPriorKeyword> getPriorKeywordList(String keyword, Integer fromSearch, Integer dynamicStatus);

    /**
     * 选择标签
     * @param keyword
     * @param fromSearch
     * @param dynamicStatus 0 为动态标签 1 静态标签
     * @return
     */
    List<KeyWord> getPickKeyword(String keyword, Integer fromSearch, Integer dynamicStatus);

    /**
     * 优先展示标签数量
     * @return
     */
    Integer getPriorCount();

    /**
     * 标签是否已经是优先展示标签
     * @param searchId
     * @return
     */
    Integer getPrior(@Param("searchId") Integer searchId);

    /**
     * 插入优先展示标签
     * @param searchId
     */
    void insertPriorKeyword(@Param("searchId") Integer searchId);

    /**
     * 删除状态更改
     * @param id
     */
    void delPriorKeyword(@Param("id") Integer id);

    /**
     * 根据标签Id删除优先展示标签
     * @param id
     */
    void delPriorKeywordById(@Param("id") Integer id);
}
