package com.caimei365.manager.dao.user;

import com.caimei365.manager.entity.caimei.CmShop;
import com.caimei365.manager.entity.caimei.ReturnEntity;
import com.caimei365.manager.entity.caimei.shopImport.*;
import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;

import java.util.List;

/**
 * Description
 *
 * @author : hzg
 * @date : 2023/12/14
 */
@Mapper
public interface CmMarketShopDao {

    /**
     * 上传营销供应商logo
     * @param id
     * @param logo
     */
    void updateShopLogo(@Param("id") Integer id, @Param("logo") String logo);

    /**
     * 数据报表数据
     * @param marketId
     * @param reportName
     * @return
     */
    List<CmMarketReport> getMarketReport(@Param("marketId") Integer marketId, @Param("reportName") String reportName);

    /**
     * 根据数据报表Id 查询报表数据
     * @param id
     * @return
     */
    CmMarketReport getMarketReportById(@Param("id") Integer id);

    /**
     * 启用数据报表
     * @param id
     */
    void updateMarketReportVisible(@Param("id") Integer id);

    /**
     * 删除数据报表
     * @param id
     */
    void updateMarketReport(@Param("id") Integer id);

    /**
     * 添加营销供应商数据报表
     * @param cmMarketReport
     */
    void insertMarketReport(CmMarketReport cmMarketReport);

    /**
     * 阶段描述
     * @param stage
     */
    void insertMarketStage(Stage stage);

    /**
     * 漏斗模型数据
     * @param funnelModel
     */
    void insertMarketFunnelModel(FunnelModel funnelModel);

    /**
     * 推文数据
     * @param articleReadVolume
     */
    void insertMarketArticleReadVolume(ArticleReadVolume articleReadVolume);

    /**
     * 展现量
     * @param impressions
     */
    void insertMarketImpressions(Impressions impressions);

    /**
     * 点击量
     * @param readVolume
     */
    void insertMarketReadVolume(ReadVolume readVolume);

    /**
     * SEO汇总
     * @param summary
     */
    void insertMarketSummary(Summary summary);

    /**
     * 访问量
     * @param visits
     */
    void insertMarketVisits(Visits visits);

    /**
     * 访客来源分布
     * @param proportion
     */
    void insertMarketProportion(Proportion proportion);

    /**
     * 页面平均时长
     * @param pageDuration
     */
    void insertMarketPageDuration(PageDuration pageDuration);

    /**
     * 广告图点击量
     * @param mallHits
     */
    void insertMarketAdvertHits(AdvertHits mallHits);

    /**
     * 咨询数量
     * @param remark
     */
    void insertMarketRemark(Remark remark);

    /**
     * 修改阶段信息
     * @param marketReportId
     * @param reportDate
     */
    void updateMarketStage(@Param("marketReportId") Integer marketReportId, @Param("reportDate") String reportDate);

    /**
     * 修改漏斗模型数据
     * @param marketReportId
     * @param reportDate
     */
    void updateMarketFunnelModel(@Param("marketReportId") Integer marketReportId, @Param("reportDate") String reportDate);

    /**
     * 修改推文数据
     * @param marketReportId
     * @param reportDate
     */
    void updateMarketArticleReadVolume(@Param("marketReportId") Integer marketReportId, @Param("reportDate") String reportDate);

    /**
     * 修改展现量
     * @param marketReportId
     * @param reportDate
     */
    void updateMarketImpressions(@Param("marketReportId") Integer marketReportId, @Param("reportDate") String reportDate);

    /**
     * 修改点击量
     * @param marketReportId
     * @param reportDate
     */
    void updateMarketReadVolume(@Param("marketReportId") Integer marketReportId, @Param("reportDate") String reportDate);

    /**
     * 修改SEO汇总数据
     * @param marketReportId
     * @param reportDate
     */
    void updateMarketSummary(@Param("marketReportId") Integer marketReportId, @Param("reportDate") String reportDate);

    /**
     * 修改访问量数据
     * @param marketReportId
     * @param reportDate
     */
    void updateMarketVisits(@Param("marketReportId") Integer marketReportId, @Param("reportDate") String reportDate);

    /**
     * 修改方可来源分布数据
     * @param marketReportId
     * @param reportDate
     */
    void updateMarketProportion(@Param("marketReportId") Integer marketReportId, @Param("reportDate") String reportDate);

    /**
     * 修改页面平均时长数据
     * @param marketReportId
     * @param reportDate
     */
    void updateMarketPageDuration(@Param("marketReportId") Integer marketReportId, @Param("reportDate") String reportDate);

    /**
     * 修改广告图点击量数据
     * @param marketReportId
     * @param reportDate
     */
    void updateMarketAdvertHits(@Param("marketReportId") Integer marketReportId, @Param("reportDate") String reportDate);

    /**
     * 修改咨询数量数据
     * @param marketReportId
     * @param reportDate
     */
    void updateMarketRemark(@Param("marketReportId") Integer marketReportId, @Param("reportDate") String reportDate);

    /**
     * 获取报表对应的供应商信息
     * @param id
     * @return
     */
    CmMarketShop getShopInfoById(@Param("id") Integer id);

    /**
     * 获取阶段描述
     * @param marketReportId
     * @return
     */
    List<Stage> getMarketStage(@Param("marketReportId") Integer marketReportId);

    /**
     * 获取漏洞模型数据
     * @param marketReportId
     * @return
     */
    List<FunnelModel> getMarketFunnelModel(@Param("marketReportId") Integer marketReportId);

    /**
     * 获取推文数据
     * @param marketReportId
     * @return
     */
    List<ArticleReadVolume> getMarketArticleReadVolume(@Param("marketReportId") Integer marketReportId);

    /**
     * 获取展现量数据
     * @param marketReportId
     * @return
     */
    List<Impressions> getMarketImpressions(@Param("marketReportId") Integer marketReportId);

    /**
     * 获取点击量数据
     * @param marketReportId
     * @return
     */
    List<ReadVolume> getMarketReadVolume(@Param("marketReportId") Integer marketReportId);

    /**
     * 获取SEO汇总数据
     * @param marketReportId
     * @return
     */
    List<Summary> getMarketSummary(@Param("marketReportId") Integer marketReportId);

    /**
     * 获取访问量数据
     * @param marketReportId
     * @return
     */
    List<Visits> getMarketVisits(@Param("marketReportId") Integer marketReportId);

    /**
     * 获取访客来源分布数据
     * @param marketReportId
     * @return
     */
    List<Proportion> getMarketProportion(@Param("marketReportId") Integer marketReportId);

    /**
     * 获取页面平均访问时长数据
     * @param marketReportId
     * @return
     */
    List<PageDuration> getMarketPageDuration(@Param("marketReportId") Integer marketReportId);

    /**
     * 获取广告图点击量数据
     * @param marketReportId
     * @return
     */
    List<AdvertHits> getMarketAdvertHits(@Param("marketReportId") Integer marketReportId);

    /**
     * 获取咨询数量数据
     * @param marketReportId
     * @return
     */
    List<Remark> getMarketRemark(@Param("marketReportId") Integer marketReportId);

    /**
     * 供应商包含的标签词
     * @param shopId
     * @return
     */
    List<String> getShopKeyword(@Param("shopId") Integer shopId);

    /**
     * 访问供应商相关用户所在地区
     * @param accessDate
     * @param labels
     * @return
     */
    List<String> getRegion(@Param("accessDate") String accessDate, @Param("labels") List<String> labels);

    /**
     * 用户身份
     * @param accessDate
     * @param labels
     * @return
     */
    List<ReturnEntity> getUserIdentity(@Param("accessDate") String accessDate, @Param("labels") List<String> labels);

    /**
     * 机构类型
     * @param accessDate
     * @param labels
     * @return
     */
    List<ReturnEntity> getClubType(@Param("accessDate") String accessDate, @Param("labels") List<String> labels);
}
