package com.caimei365.manager.service.caimei;

import com.caimei365.manager.utils.OSSUtils;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;
import org.springframework.web.multipart.MultipartFile;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.io.File;
import java.io.FileInputStream;
import java.io.IOException;
import java.io.OutputStream;
import java.net.URLEncoder;
import java.util.HashMap;
import java.util.Map;
import java.util.UUID;

/**
 * Description
 *
 * @author : Charles
 * @date : 2023/9/18
 */
@Service
@Slf4j
public class CmOssArchiveService {

    @Resource private OSSUtils ossUtils;

    public void download(HttpServletRequest request, HttpServletResponse response, String fileName) throws IOException {
        File file = new File("./" + fileName);
        //  文件存在才下载
        if (file.exists()) {
            OutputStream out = null;
            FileInputStream in = null;
            try {
                // 1.读取要下载的内容
                in = new FileInputStream(file);

                // 2. 告诉浏览器下载的方式以及一些设置
                // 解决文件名乱码问题，获取浏览器类型，转换对应文件名编码格式，IE要求文件名必须是utf-8, firefo要求是iso-8859-1编码
                String agent = request.getHeader("user-agent");
                if (agent.contains("FireFox")) {
                    fileName = new String(fileName.getBytes("UTF-8"), "iso-8859-1");
                } else {
                    fileName = URLEncoder.encode(fileName, "UTF-8");
                }
                // 设置下载文件的mineType，告诉浏览器下载文件类型
                String mineType = request.getServletContext().getMimeType(fileName);
                response.setContentType(mineType);
                // 设置一个响应头，无论是否被浏览器解析，都下载
                response.setHeader("Content-disposition", "attachment; filename=" + fileName);
                // 将要下载的文件内容通过输出流写到浏览器
                out = response.getOutputStream();
                int len = 0;
                byte[] buffer = new byte[1024];
                while ((len = in.read(buffer)) > 0) {
                    out.write(buffer, 0, len);
                }
            } catch (IOException e) {
                e.printStackTrace();
            } finally {
                if (out != null) {
                    out.close();
                }
                if (in != null) {
                    in.close();
                }
                file.delete();
            }
        }
    }

    public Map<String, Object> fileUpload(MultipartFile multipartFile) {
        Map<String, Object> map = new HashMap<>();
        String fileAllName = multipartFile.getOriginalFilename();
        String fileType = fileAllName.substring(fileAllName.lastIndexOf(".") + 1);
        String uuid = UUID.randomUUID().toString().replaceAll("-", "");
        String filePath = uuid + "." + fileType;
        String contentType = ossUtils.getContentType(fileAllName);
        try {
            //保存本地
            File file = ossUtils.ossUpload(multipartFile);
            log.info("默认路径>>>" + file.getAbsolutePath());
            //上传oss
            String url = ossUtils.ossUpload(filePath, file, contentType);
            //删除本地文件
            ossUtils.deleteFile(file);
            map.put("success", true);
            map.put("msg", "操作成功");
            map.put("url", url);
            map.put("fileName", fileAllName);
            map.put("ossName", filePath);
        } catch (Exception e) {
            e.printStackTrace();
            map.put("success", false);
            map.put("msg", "操作失败");
            log.info("上传异常！！！");
        }
        return map;
    }

    public void fileDownload(String ossName, String fileName, HttpServletRequest request, HttpServletResponse response) throws IOException {
        ossUtils.downFile(ossName, fileName);
        download(request, response, fileName);
    }

    public void deleteOssFile(String ossName) {
        //删除oss服务器上的文件
        ossUtils.deleteSingleFile(ossName);
    }
}
