package com.caimei365.manager.service.caimei.listener;

import com.alibaba.excel.context.AnalysisContext;
import com.alibaba.excel.event.AnalysisEventListener;
import com.caimei365.manager.dao.user.CmMarketShopDao;
import com.caimei365.manager.entity.caimei.shopImport.ArticleReadVolume;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;

import java.util.ArrayList;
import java.util.List;

/**
 * Description
 *
 * @author : hzg
 * @date : 2023/11/22
 */
@Slf4j
public class ArticleReadVolumeListener extends AnalysisEventListener<ArticleReadVolume> {

    private Integer marketReportId;

    private CmMarketShopDao marketShopDao;

    private final Integer SIZE = 100;

    private final List<ArticleReadVolume> dataList = new ArrayList();

    public ArticleReadVolumeListener(Integer marketReportId, CmMarketShopDao marketShopDao) {
        this.marketReportId = marketReportId;
        this.marketShopDao = marketShopDao;
    }

    /**
     * 数据解析
     * @param data
     * @param analysisContext
     */
    @Override
    public void invoke(ArticleReadVolume data, AnalysisContext analysisContext) {
        dataList.add(data);
        if (dataList.size() >= SIZE) {
            saveData(dataList);
            dataList.clear();
        }
    }

    /**
     * 解析完成调用
     * @param analysisContext
     */
    @Override
    public void doAfterAllAnalysed(AnalysisContext analysisContext) {
        System.out.println("-----------推文阅读量----------");
        System.out.println("dataList======="+dataList);
        saveData(dataList);
    }

    @Override
    public boolean hasNext(AnalysisContext analysisContext) {
        return true;
    }

    /**
     * 保存数据
     */
    public void saveData(List<ArticleReadVolume> dataList) {
        dataList.forEach(articleReadVolume -> {
            articleReadVolume.setMarketReportId(marketReportId);
            marketShopDao.insertMarketArticleReadVolume(articleReadVolume);
        });
    }
}
